@@ -57,9 +57,7 @@ class CfnCluster(
         parameter_group_name: typing.Optional[str] = None,
         preferred_maintenance_window: typing.Optional[str] = None,
         security_group_ids: typing.Optional[typing.List[str]] = None,
-        sse_specification: typing.Optional[
-            typing.Union[aws_cdk.core.IResolvable, "SSESpecificationProperty"]
-        ] = None,
+        sse_specification: typing.Optional[typing.Union[aws_cdk.core.IResolvable, "SSESpecificationProperty"]] = None,
         subnet_group_name: typing.Optional[str] = None,
         tags: typing.Any = None,
     ) -> None:
@@ -99,34 +97,6 @@ class CfnCluster(
 
         jsii.create(CfnCluster, self, [scope, id, props])
 
-    @jsii.member(jsii_name="fromCloudFormation")
-    @builtins.classmethod
-    def from_cloud_formation(
-        cls,
-        scope: aws_cdk.core.Construct,
-        id: str,
-        resource_attributes: typing.Any,
-        *,
-        finder: aws_cdk.core.ICfnFinder,
-    ) -> "CfnCluster":
-        """A factory method that creates a new instance of this class from an object containing the CloudFormation properties of this resource.
-
-        Used in the @aws-cdk/cloudformation-include module.
-
-        :param scope: -
-        :param id: -
-        :param resource_attributes: -
-        :param finder: The finder interface used to resolve references across the template.
-
-        stability
-        :stability: experimental
-        """
-        options = aws_cdk.core.FromCloudFormationOptions(finder=finder)
-
-        return jsii.sinvoke(
-            cls, "fromCloudFormation", [scope, id, resource_attributes, options]
-        )
-
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: aws_cdk.core.TreeInspector) -> None:
         """Examines the CloudFormation resource and discloses attributes.
@@ -330,9 +300,7 @@ class CfnCluster(
     @jsii.member(jsii_name="sseSpecification")
     def sse_specification(
         self,
-    ) -> typing.Optional[
-        typing.Union[aws_cdk.core.IResolvable, "SSESpecificationProperty"]
-    ]:
+    ) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, "SSESpecificationProperty"]]:
         """``AWS::DAX::Cluster.SSESpecification``.
 
         see
@@ -343,9 +311,7 @@ class CfnCluster(
     @sse_specification.setter
     def sse_specification(
         self,
-        value: typing.Optional[
-            typing.Union[aws_cdk.core.IResolvable, "SSESpecificationProperty"]
-        ],
+        value: typing.Optional[typing.Union[aws_cdk.core.IResolvable, "SSESpecificationProperty"]],
     ) -> None:
         jsii.set(self, "sseSpecification", value)
 
@@ -372,9 +338,7 @@ class CfnCluster(
         def __init__(
             self,
             *,
-            sse_enabled: typing.Optional[
-                typing.Union[bool, aws_cdk.core.IResolvable]
-            ] = None,
+            sse_enabled: typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]] = None,
         ) -> None:
             """
             :param sse_enabled: ``CfnCluster.SSESpecificationProperty.SSEEnabled``.
@@ -442,11 +406,7 @@ class CfnClusterProps:
         parameter_group_name: typing.Optional[str] = None,
         preferred_maintenance_window: typing.Optional[str] = None,
         security_group_ids: typing.Optional[typing.List[str]] = None,
-        sse_specification: typing.Optional[
-            typing.Union[
-                aws_cdk.core.IResolvable, "CfnCluster.SSESpecificationProperty"
-            ]
-        ] = None,
+        sse_specification: typing.Optional[typing.Union[aws_cdk.core.IResolvable, "CfnCluster.SSESpecificationProperty"]] = None,
         subnet_group_name: typing.Optional[str] = None,
         tags: typing.Any = None,
     ) -> None:
@@ -588,9 +548,7 @@ class CfnClusterProps:
     @builtins.property
     def sse_specification(
         self,
-    ) -> typing.Optional[
-        typing.Union[aws_cdk.core.IResolvable, "CfnCluster.SSESpecificationProperty"]
-    ]:
+    ) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, "CfnCluster.SSESpecificationProperty"]]:
         """``AWS::DAX::Cluster.SSESpecification``.
 
         see
@@ -667,34 +625,6 @@ class CfnParameterGroup(
 
         jsii.create(CfnParameterGroup, self, [scope, id, props])
 
-    @jsii.member(jsii_name="fromCloudFormation")
-    @builtins.classmethod
-    def from_cloud_formation(
-        cls,
-        scope: aws_cdk.core.Construct,
-        id: str,
-        resource_attributes: typing.Any,
-        *,
-        finder: aws_cdk.core.ICfnFinder,
-    ) -> "CfnParameterGroup":
-        """A factory method that creates a new instance of this class from an object containing the CloudFormation properties of this resource.
-
-        Used in the @aws-cdk/cloudformation-include module.
-
-        :param scope: -
-        :param id: -
-        :param resource_attributes: -
-        :param finder: The finder interface used to resolve references across the template.
-
-        stability
-        :stability: experimental
-        """
-        options = aws_cdk.core.FromCloudFormationOptions(finder=finder)
-
-        return jsii.sinvoke(
-            cls, "fromCloudFormation", [scope, id, resource_attributes, options]
-        )
-
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: aws_cdk.core.TreeInspector) -> None:
         """Examines the CloudFormation resource and discloses attributes.
@@ -881,34 +811,6 @@ class CfnSubnetGroup(
 
         jsii.create(CfnSubnetGroup, self, [scope, id, props])
 
-    @jsii.member(jsii_name="fromCloudFormation")
-    @builtins.classmethod
-    def from_cloud_formation(
-        cls,
-        scope: aws_cdk.core.Construct,
-        id: str,
-        resource_attributes: typing.Any,
-        *,
-        finder: aws_cdk.core.ICfnFinder,
-    ) -> "CfnSubnetGroup":
-        """A factory method that creates a new instance of this class from an object containing the CloudFormation properties of this resource.
-
-        Used in the @aws-cdk/cloudformation-include module.
-
-        :param scope: -
-        :param id: -
-        :param resource_attributes: -
-        :param finder: The finder interface used to resolve references across the template.
-
-        stability
-        :stability: experimental
-        """
-        options = aws_cdk.core.FromCloudFormationOptions(finder=finder)
-
-        return jsii.sinvoke(
-            cls, "fromCloudFormation", [scope, id, resource_attributes, options]
-        )
-
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: aws_cdk.core.TreeInspector) -> None:
         """Examines the CloudFormation resource and discloses attributes.
